// SASAX-RSS: RSS(RDF Site Summary) parser by SASAX
// Copyright (C) 2004 FUJIWARA Katsunori(foozy@lares.dti.ne.jp)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package jp.ne.dti.lares.foozy.sasax.rss;

import java.io.InputStreamReader;

import jp.ne.dti.lares.foozy.sasax.CompositeElement;
import jp.ne.dti.lares.foozy.sasax.Element;
import jp.ne.dti.lares.foozy.sasax.ElementDrivenHandler;
import jp.ne.dti.lares.foozy.sasax.ElementRepetition;

/**
 * Class to parse XML document as RSS.
 *
 * <p>This has "MUST ITEM"s as shown below:</p>
 *
 * <ul>
 * <li>{@link #channel channel} element
 * <li>{@link #repetition repetition} of {@link #item item} element
 * </ul>
 *
 * <p>This has "OPTIONAL ITEM"s as shown below:</p>
 *
 * <ul>
 * <li>{@link #image image} element
 * <li>{@link #textinput textinput} element
 * </ul>
 *
 * <p>This does:</p>
 *
 * <ul>
 * <li>expect to be named as
 * {@link RDF#RDF "RDF"} of {@link RDF#NS_URI rdf}
 * <li>not care about order of sub elements
 * <li>not accept unknown sub elements
 * </ul>
 *
 * @author FUJIWARA Katsunori &lt;foozy@lares.dti.ne.jp&gt;(code/doc)
 */
public class RSSRootElement
    extends CompositeElement //
{
    /**
     * "channel" sub element.
     */
    final
    public ChannelElement channel = new ChannelElement(this);

    /**
     * "image" sub element.
     */
    final
    public ImageElement image = new ImageElement(this);

    /**
     * Repetition of "item" element.
     */
    final
    public ElementRepetition repetition = new ElementRepetition(this);

    /**
     * Repeated "item" element.
     */
    final
    public ItemElement item = new ItemElement(repetition);

    /**
     * "textinput" sub element.
     */
    final
    public TextinputElement textinput = new TextinputElement(this);

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Constructor.
     *
     * @param parent of this element
     */
    public RSSRootElement(Element parent){
        super(parent, RDF.NS_URI, RDF.RDF, false, false);

        repetition.setElement(item);

        addMustItem(channel);
        addMustItem(repetition);
        addOptionalItem(image);
        addOptionalItem(textinput);
    }

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Bootstrap RSS parser.
     *
     * <p>This tries to read file, whose name is specified as first argument,
     * and parse it by <code>RSSRoot</code> on SASAX framework.</p>
     * <p>This makes empty output when success to parse XML document.</p>
     */
    static
    public void main(String[] args)
        throws Exception //
    {
        InputStreamReader reader = null;
        try{
            RSSRootElement root = new RSSRootElement(null);
            ElementDrivenHandler handler = new ElementDrivenHandler(root);
            reader = new InputStreamReader(System.in, "UTF8");
            handler.parse(reader);
        }
        finally{
            if(null != reader){ reader.close(); }
        }
    }
}
