// SASAX-RSS: RSS(RDF Site Summary) parser by SASAX
// Copyright (C) 2004 FUJIWARA Katsunori(foozy@lares.dti.ne.jp)
// 
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
// IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
// CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
// TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
// SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package jp.ne.dti.lares.foozy.sasax.rss;

import jp.ne.dti.lares.foozy.sasax.CompositeElement;
import jp.ne.dti.lares.foozy.sasax.Element;
import jp.ne.dti.lares.foozy.sasax.StringElement;

/**
 * Class to parse "textinput" element of RSS.
 *
 * <p>This has "MUST ITEM"s as shown below:</p>
 *
 * <ul>
 * <li>{@link #title title} element
 * <li>{@link #description description} element
 * <li>{@link #name name} element
 * <li>{@link #link link} element
 * </ul>
 *
 * <p>This has no "OPTIONAL ITEM".</p>
 *
 * <p>This does:</p>
 *
 * <ul>
 * <li>expect to be named as
 * {@link RSS#ITEM "textinput"} of {@link RSS#NS_URI rss}
 * <li>expect attribte named as
 * {@link RDF#ABOUT "about"} of {@link RDF#NS_URI rdf} 
 * <li>not care about order of sub elements
 * <li>ignore unknown sub elements
 * </ul>
 *
 * @author FUJIWARA Katsunori &lt;foozy@lares.dti.ne.jp&gt;(code/doc)
 */
public class TextinputElement
    extends CompositeElement //
{
    /**
     * "title" sub element.
     *
     * <p>This does:</p>
     *
     * <ul>
     * <li>expect to be named as
     * {@link RSS#TITLE "title"} of {@link RSS#NS_URI rss}
     * <li>expect only text under itself
     * </ul>
     *
     * <p>This element is registered as "MUST ITEM" of this.</p>
     */
    final
    public StringElement title =
    new StringElement(this, RSS.NS_URI, RSS.TITLE);

    /**
     * "description" sub element.
     *
     * <p>This does:</p>
     *
     * <ul>
     * <li>expect to be named as
     * {@link RSS#DESCRIPTION "description"} of {@link RSS#NS_URI rss}
     * <li>expect only text under itself
     * </ul>
     *
     * <p>This element is registered as "MUST ITEM" of this.</p>
     */
    final
    public StringElement description =
    new StringElement(this, RSS.NS_URI, RSS.DESCRIPTION);

    /**
     * "name" sub element.
     *
     * <p>This does:</p>
     *
     * <ul>
     * <li>expect to be named as
     * {@link RSS#NAME "name"} of {@link RSS#NS_URI rss}
     * <li>expect only text under itself
     * </ul>
     *
     * <p>This element is registered as "MUST ITEM" of this.</p>
     */
    final
    public StringElement name =
    new StringElement(this, RSS.NS_URI, RSS.NAME);

    /**
     * "link" sub element.
     *
     * <p>This does:</p>
     *
     * <ul>
     * <li>expect to be named as
     * {@link RSS#LINK "link"} of {@link RSS#NS_URI rss}
     * <li>expect only text under itself
     * </ul>
     *
     * <p>This element is registered as "MUST ITEM" of this.</p>
     */
    final
    public StringElement link =
    new StringElement(this, RSS.NS_URI, RSS.LINK);

    ///////////////////////////////////////////////////////////////////////////

    /**
     * Constructor.
     *
     * @param parent of this element
     */
    public TextinputElement(Element parent){
        super(parent, RSS.NS_URI, RSS.TEXTINPUT, true, false);

        addMustItem(title);
        addMustItem(description);
        addMustItem(name);
        addMustItem(link);

        addNotification(EnsureRDFAbout.CHECKER);
    }

    ///////////////////////////////////////////////////////////////////////////
}
